==> JOB-3.1.2.tar.gz: JOB-3.1.2/ob/src/org/omg/CORBA/portable/Delegate.java <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

package org.omg.CORBA.portable;

public abstract class Delegate
{
    public abstract boolean
    is_a(org.omg.CORBA.Object self, String repository_id);

    public abstract boolean
    is_equivalent(org.omg.CORBA.Object self, org.omg.CORBA.Object rhs);

    public abstract boolean
    non_existent(org.omg.CORBA.Object self);

    public abstract int
    hash(org.omg.CORBA.Object self, int max);

    public abstract org.omg.CORBA.Object
    duplicate(org.omg.CORBA.Object self);

    public abstract void
    release(org.omg.CORBA.Object self);

    public abstract org.omg.CORBA.ImplementationDef
    get_implementation(org.omg.CORBA.Object self);

    public abstract org.omg.CORBA.InterfaceDef
    get_interface(org.omg.CORBA.Object self);

    public abstract org.omg.CORBA.Request
    request(org.omg.CORBA.Object self, String operation);

    public abstract org.omg.CORBA.Request
    create_request(org.omg.CORBA.Object self, org.omg.CORBA.Context ctx,
		   String operation, org.omg.CORBA.NVList arg_list,
		   org.omg.CORBA.NamedValue result);

    public abstract org.omg.CORBA.Request
    create_request(org.omg.CORBA.Object self, org.omg.CORBA.Context ctx,
		   String operation, org.omg.CORBA.NVList arg_list,
		   org.omg.CORBA.NamedValue result,
		   org.omg.CORBA.ExceptionList excepts,
		   org.omg.CORBA.ContextList contexts);

    public abstract org.omg.CORBA.ORB
    orb(org.omg.CORBA.Object self);

    public abstract org.omg.CORBA.Policy
    get_policy(int policy_type);

    public abstract org.omg.CORBA.Policy
    get_effective_policy_override(int policy_type);

    public abstract org.omg.CORBA.Object
    set_policy_overrides(org.omg.CORBA.Policy[] np,
			 org.omg.CORBA.SetOverrideType set_add)
	throws org.omg.CORBA.PolicyManagerPackage.InvalidPolicies;

    public abstract org.omg.CORBA.Policy[]
    get_policy_overrides(int[] types);

    public abstract boolean
    validate_policies(org.omg.CORBA.Policy[] inconsistent_policies);

    public abstract org.omg.CORBA.DomainManager[]
    get_domain_managers();
}

==> JOB-3.3.2.tar.gz: JOB-3.3.2/ob/src/org/omg/CORBA/portable/Delegate.java <==
// **********************************************************************
//
// Copyright (c) 2000
// Object Oriented Concepts, Inc.
// Billerica, MA, USA
//
// All Rights Reserved
//
// **********************************************************************

package org.omg.CORBA.portable;

public abstract class Delegate
{
    public abstract boolean
    is_a(org.omg.CORBA.Object self, String repository_id);

    public abstract boolean
    is_equivalent(org.omg.CORBA.Object self, org.omg.CORBA.Object rhs);

    public abstract boolean
    non_existent(org.omg.CORBA.Object self);

    public abstract int
    hash(org.omg.CORBA.Object self, int max);

    public abstract org.omg.CORBA.Object
    duplicate(org.omg.CORBA.Object self);

    public abstract void
    release(org.omg.CORBA.Object self);

    public abstract org.omg.CORBA.ImplementationDef
    get_implementation(org.omg.CORBA.Object self);

    public abstract org.omg.CORBA.InterfaceDef
    get_interface(org.omg.CORBA.Object self);

    public abstract org.omg.CORBA.Request
    request(org.omg.CORBA.Object self, String operation);

    public abstract org.omg.CORBA.Request
    create_request(org.omg.CORBA.Object self, org.omg.CORBA.Context ctx,
		   String operation, org.omg.CORBA.NVList arg_list,
		   org.omg.CORBA.NamedValue result);

    public abstract org.omg.CORBA.Request
    create_request(org.omg.CORBA.Object self, org.omg.CORBA.Context ctx,
		   String operation, org.omg.CORBA.NVList arg_list,
		   org.omg.CORBA.NamedValue result,
		   org.omg.CORBA.ExceptionList excepts,
		   org.omg.CORBA.ContextList contexts);

    //
    // For compatibility with JDK 1.2
    //

    public abstract org.omg.CORBA.Object
    get_interface_def(org.omg.CORBA.Object self);

    public abstract org.omg.CORBA.Policy
    get_policy(org.omg.CORBA.Object self, int policy_type);

    public abstract org.omg.CORBA.Object
    set_policy_override(org.omg.CORBA.Object self,
                        org.omg.CORBA.Policy[] np,
                        org.omg.CORBA.SetOverrideType set_add);

    public abstract org.omg.CORBA.DomainManager[]
    get_domain_managers(org.omg.CORBA.Object self);

    public abstract org.omg.CORBA.ORB
    orb(org.omg.CORBA.Object self);

    //
    // ORBacus specific
    //

    public abstract org.omg.CORBA.Object
    set_policy_overrides(org.omg.CORBA.Policy[] np,
			 org.omg.CORBA.SetOverrideType set_add)
	throws org.omg.CORBA.PolicyManagerPackage.InvalidPolicies;

    public abstract org.omg.CORBA.Policy
    get_effective_policy_override(int policy_type);

    public abstract org.omg.CORBA.Policy[]
    get_policy_overrides(int[] types);

    public abstract boolean
    validate_policies(org.omg.CORBA.Policy[] inconsistent_policies);
}
